@@ -1,4 +1,3 @@
-import sys
 from typing import Union
 from python_search.environment import is_mac
 
@@ -41,10 +40,11 @@ class Clipboard:
         :return:
         """
 
-        if not content and has_stdin():
+        if not content:
+            import sys
 
             data = sys.stdin.readlines()
-            content = "\n".join(data)
+            content = "".join(data)
 
         if not content:
             raise Exception("Tryring to set empty to clipboard")
@@ -52,40 +52,27 @@ class Clipboard:
         if type(content) != str:
             raise Exception("Tryring to set a non string to clipboard")
 
-        def shellquote(s):
-            return "'" + s.replace("'", "'") + "'"
-
-        sanitized = shellquote(content)
+        # overrides previous content
+        with open("/tmp/clipboard_content", "w") as f:
+            f.write(content)
 
         clipboard_cmd = "xsel --clipboard --primary --input"
         if is_mac():
             clipboard_cmd = "pbcopy"
 
-        cmd = f"echo {sanitized} | {clipboard_cmd}"
+        cmd = f"cat /tmp/clipboard_content | {clipboard_cmd}"
+
+        from subprocess import PIPE, Popen
+
+        with Popen(cmd, stdout=PIPE, stderr=None, shell=True) as process:
+            output = process.communicate()[0].decode("utf-8")
+            if process.returncode != 0:
+                raise Exception("Failed to copy to clipboard " + output)
 
         if enable_notifications or notify:
             from python_search.apps.notification_ui import send_notification
 
-            send_notification(f"Content copied: {sanitized}")
-
-        import os
-
-        print(cmd)
-        return os.system(cmd)
-
-
-def has_stdin() -> bool:
-    import select
-    import sys
-
-    return select.select(
-        [
-            sys.stdin,
-        ],
-        [],
-        [],
-        0.0,
-    )[0]
+            send_notification(f"Content copied: {content}")
 
 
 def main():
